#
# spec file for package kured
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# nodebuginfo


Name:           kured
Version:        1.15.1
Release:        1.3
Summary:        Kubernetes daemonset to perform safe automatic node reboots
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/weaveworks/kured
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
Patch0:         systemctl-path.patch
Patch1:         kured-imagePullPolicy.patch
BuildRequires:  golang(API) >= 1.20

%description
Kured (KUbernetes REboot Daemon) is a Kubernetes daemonset that
performs safe automatic node reboots when the need to do so is
indicated by the package management system of the underlying OS.

- Watches for the presence of a reboot sentinel e.g. %{_localstatedir}/run/reboot-required

- Utilises a lock in the API server to ensure only one node reboots at a time

- Optionally defers reboots in the presence of active Prometheus alerts

- Cordons & drains worker nodes before reboot, uncordoning them after

%package k8s-yaml
Summary:        Kubernetes yaml file to run kured container
Group:          System/Management
BuildArch:      noarch

%description k8s-yaml
This package contains the yaml file requried to download and run the
kured container in a kubernetes cluster.

%prep
%autosetup -a 1 -p 1

%build
%ifnarch ppc64
export GOFLAGS="-buildmode=pie"
%endif
go build ./cmd/%{name}

%check
# execute the binary as a basic check
./%{name} --help

%install
install -D -m 0755 %{name} "%{buildroot}/%{_bindir}/%{name}"

# Install provided yaml file to download and run the kured container
mkdir -p %{buildroot}%{_datadir}/k8s-yaml/kured
cat kured-rbac.yaml kured-ds.yaml > %{buildroot}%{_datadir}/k8s-yaml/kured/kured.yaml
chmod 644  %{buildroot}%{_datadir}/k8s-yaml/kured/kured.yaml
sed -i -e 's|image: .*|image: registry.opensuse.org/kubic/kured:%{version}|g' %{buildroot}%{_datadir}/k8s-yaml/kured/kured.yaml

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files k8s-yaml
%dir %{_datarootdir}/k8s-yaml
%dir %{_datarootdir}/k8s-yaml/kured
%{_datarootdir}/k8s-yaml/kured/kured.yaml

%changelog
* Sun Mar 24 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Packaging improvements:
  * Rebase kured-imagePullPolicy.patch
  * Rebase systemctl-path.patch
  * _service change disabled to manual per osc deprecation warning:
    WARNING: Command 'disabledrun/dr' is obsolete, please convert
    your _service to use 'manual' and then 'manualrun/mr' instead.
  * Update to BuildRequires: golang(API) >= 1.20 matching go.mod
  * Re-enable binary stripping and debuginfo boo#1210938
  * Drop BuildRequires: go-md2man and use plain markdown as %%doc
  * Drop BuildRequires: fdupes and usage during install step. Go
    application packages have a small number of installed files and
    this hasn't been an issue following the transition from GOPATH
  * Drop ExcludeArch: s390
  * Remove ldflags -X entries for upstream import path and version.
    This information is embedded in binaries with go1.18+ and
    available via go version -m or runtime/debug.ReadBuildInfo().
  * Remove define git commit ref no longer needed
  * Build PIE with pattern that may become recommended procedure:
    %%%%ifnarch ppc64 GOFLAGS="-buildmode=pie" %%%%endif go build
    A go toolchain buildmode default config would be preferable
    but none exist at this time.
  * Drop mod=vendor, go1.14+ will detect vendor dir and auto-enable
  * Add basic %%check to execute binary --help
* Sun Mar 24 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.15.1:
  * chore: update to 1.15.1
  * update bootstrap tools
  * update k8s deps
  * build(deps): bump google.golang.org/protobuf from 1.32.0 to 1.33.0
  * build(deps): bump guyarb/golang-test-annoations from 0.7.0 to 0.8.0
  * build(deps): bump github.com/stretchr/testify from 1.8.4 to 1.9.0
  * build(deps): bump aquasecurity/trivy-action from 0.17.0 to 0.18.0 (#905)
  * build(deps): bump github.com/prometheus/client_golang
  * build(deps): bump github.com/prometheus/common from 0.47.0 to 0.48.0
  * Update k8s deps (#901)
  * build(deps): bump github.com/prometheus/common from 0.46.0 to 0.47.0
  * build(deps): bump helm/kind-action from 1.8.0 to 1.9.0
  * build(deps): bump aquasecurity/trivy-action from 0.16.1 to 0.17.0
  * build(deps): bump nick-invision/retry from 2.9.0 to 3.0.0 (#892)
  * build(deps): bump docker/metadata-action from 5.5.0 to 5.5.1 (#893)
  * build(deps): bump lycheeverse/lychee-action from 1.9.2 to 1.9.3
  * build(deps): bump alpine from 3.19.0 to 3.19.1
  * build(deps): bump lycheeverse/lychee-action from 1.9.1 to 1.9.2
* Sun Mar 24 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.15.0:
  * feat: update to 1.15.0 (#887)
  * build(deps): bump github.com/prometheus/common from 0.45.0 to 0.46.0 (#885)
  * build(deps): bump lycheeverse/lychee-action from 1.9.0 to 1.9.1
  * build(deps): bump actions/checkout from 3 to 4
  * build(deps): bump actions/setup-go from 4 to 5 (#882)
  * build(deps): bump docker/setup-qemu-action from 2 to 3
  * build(deps): bump nick-invision/retry from 2.8.3 to 2.9.0 (#880)
  * build(deps): bump docker/setup-buildx-action from 2 to 3 (#879)
  * build(deps): bump kubereboot/kured from 1.13.2 to 1.14.2 (#877)
  * ci: update k8s test matrix (#883)
  * Add signal-reboot (#814)
  * build(deps): bump lycheeverse/lychee-action from 1.8.0 to 1.9.0
  * build(deps): bump docker/metadata-action from 5.4.0 to 5.5.0
  * build(deps): bump aquasecurity/trivy-action from 0.16.0 to 0.16.1
  * build(deps): bump github.com/prometheus/client_golang
  * build(deps): bump github.com/spf13/viper from 1.18.1 to 1.18.2
  * build(deps): bump docker/metadata-action from 5.3.0 to 5.4.0
  * update k8s image versions
  * update k8s deps
  * build(deps): bump github/codeql-action from 2 to 3
  * feat: add drain delay (#852)
  * build(deps): bump aquasecurity/trivy-action from 0.15.0 to 0.16.0
* Sun Mar 24 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.14.2:
  * build(deps): bump alpine from 3.18.5 to 3.19.0
  * build(deps): bump github.com/spf13/viper from 1.18.0 to 1.18.1
  * update for 1.14.2 release
  * build(deps): bump actions/stale from 8 to 9
  * build(deps): bump github.com/spf13/viper from 1.17.0 to 1.18.0
  * build(deps): bump actions/setup-go from 4 to 5
  * build(deps): bump aquasecurity/trivy-action from 0.14.0 to 0.15.0
  * build(deps): bump docker/metadata-action from 5.2.0 to 5.3.0
  * build(deps): bump docker/metadata-action from 5.1.0 to 5.2.0
  * build(deps): bump alpine from 3.18.4 to 3.18.5
  * build(deps): bump docker/metadata-action from 5.0.0 to 5.1.0
  * doc: rename myself (#851)
* Sun Mar 24 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.14.1:
  * update 'update instructions'
  * prepare new release
  * build(deps): bump aquasecurity/trivy-action from 0.13.1 to 0.14.0
  * build(deps): bump github.com/spf13/cobra from 1.7.0 to 1.8.0
  * build(deps): bump aquasecurity/trivy-action from 0.13.0 to 0.13.1 (#846)
  * build(deps): bump aquasecurity/trivy-action from 0.12.0 to 0.13.0
  * build(deps): bump github.com/prometheus/common from 0.44.0 to 0.45.0
  * update x/net dependency
  * update k8s dependencies
  * build(deps): bump github.com/spf13/viper from 1.16.0 to 1.17.0
  * build(deps): bump alpine from 3.18.3 to 3.18.4
  * build(deps): bump github.com/prometheus/client_golang
  * build(deps): bump nick-invision/retry from 2.8.3 to 2.9.0
  * build(deps): bump gotest.tools/v3 from 3.5.0 to 3.5.1
  * build(deps): bump docker/setup-buildx-action from 2 to 3
  * build(deps): bump docker/metadata-action from 4.6.0 to 5.0.0
  * build(deps): bump docker/build-push-action from 4 to 5
  * build(deps): bump docker/login-action from 2 to 3
  * build(deps): bump docker/setup-qemu-action from 2 to 3
  * Fix the goreleaser architecture for arm and ppc (#824)
  * build(deps): bump actions/checkout from 3 to 4
  * build(deps): bump aquasecurity/trivy-action from 0.11.2 to 0.12.0
  * build(deps): bump github.com/containrrr/shoutrrr from 0.7.1 to 0.8.0
* Sun Mar 24 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.14.0:
  * feat: change manifest for 1.14.0 (#820)
  * build: confirm cosign prompt
  * fix: don’t hold node lock if reboot is blocked (#819)
  * feat: use go@1.20, k8s@0.27.4, test k8s 1.26-1.28 (#818)
  * cleanup: updated build-tools (#809)
  * add argument to invert the behavior of alert-filter-regexp (#786)
  * Add multiple concurrent node reboot feature (#660)
  * build(deps): bump alpine from 3.18.2 to 3.18.3
  * Adds new flag --metrics-host (#811)
  * fix: log on unusual sentinel-command exit code (#806)
  * feat: use readOnlyRootFilesystem (#805)
  * Support pod-selector for drain command (#788)
* Sun Mar 24 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.13.2:
  * chore: update manifest version
  * update k8s components/images
  * build(deps): bump guyarb/golang-test-annoations from 0.6.0 to 0.7.0 (#801)
  * build(deps): bump helm/kind-action from 1.7.0 to 1.8.0
  * build(deps): bump gotest.tools/v3 from 3.4.0 to 3.5.0 (#789)
  * build(deps): bump alpine from 3.18.0 to 3.18.2
  * build(deps): bump github.com/prometheus/client_golang
  * build(deps): bump docker/metadata-action from 4.5.0 to 4.6.0
  * build(deps): bump aquasecurity/trivy-action from 0.11.0 to 0.11.2
  * feat: metrics port command (#780)
* Sun Mar 24 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.13.1:
  * release 1.13.1 (#779)
  * build(deps): bump docker/metadata-action from 4.4.0 to 4.5.0
  * update k8s deps
  * build(deps): bump aquasecurity/trivy-action from 0.10.0 to 0.11.0
  * build(deps): bump github.com/sirupsen/logrus from 1.9.2 to 1.9.3
  * build(deps): bump github.com/stretchr/testify from 1.8.3 to 1.8.4
  * build(deps): bump github.com/spf13/viper from 1.15.0 to 1.16.0 (#773)
  * build(deps): bump github.com/prometheus/common from 0.43.0 to 0.44.0
  * build(deps): bump github.com/stretchr/testify from 1.8.2 to 1.8.3
  * build(deps): bump github.com/sirupsen/logrus from 1.9.0 to 1.9.2
  * build(deps): bump helm/kind-action from 1.6.0 to 1.7.0 (#767)
  * build(deps): bump helm/kind-action from 1.5.0 to 1.6.0 (#766)
  * build(deps): bump lycheeverse/lychee-action from 1.7.0 to 1.8.0
  * build(deps): bump alpine from 3.17.3 to 3.18.0
  * update Daniel's entry
  * build(deps): bump github.com/prometheus/common from 0.42.0 to 0.43.0 (#762)
  * build(deps): bump github.com/prometheus/client_golang
* Sun Mar 24 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.13.0:
  * Update go-restful and prepare 1.13.0 (#760)
  * update to new k8s releases
  * update docs location (#758)
  * build(deps): bump aquasecurity/trivy-action from 0.9.2 to 0.10.0
  * build(deps): bump lycheeverse/lychee-action from 1.6.1 to 1.7.0
  * build(deps): bump docker/metadata-action from 4.3.0 to 4.4.0
  * fix: annotate nodes for reboot before aborting due to blocked (#749)
  * build(deps): bump github.com/prometheus/client_golang
  * update k8s dependencies and test images for k8s release (#747)
  * build(deps): bump github.com/spf13/cobra from 1.6.1 to 1.7.0
  * build(deps): bump alpine from 3.17.2 to 3.17.3
  * build(deps): bump actions/stale from 7 to 8 (#748)
  * build(deps): bump actions/setup-go from 3 to 4
* Sun Mar 24 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.12.2:
  * chore: prepare release 1.12.2
  * Add ports config to DaemonSet yaml. Closes #741 (#742)
  * build(deps): bump github.com/prometheus/common from 0.41.0 to 0.42.0
  * build(deps): bump aquasecurity/trivy-action from 0.9.1 to 0.9.2
  * build(deps): bump github.com/prometheus/common from 0.40.0 to 0.41.0
  * update Go to 1.19, it's used in k8s 1.24 as well
  * lychee: exclude slack:// and teams:// urls as well
  * Try to dropping golang.org/x/text replacement
  * build(deps): bump github.com/stretchr/testify from 1.8.1 to 1.8.2
  * build(deps): bump lycheeverse/lychee-action from 1.5.4 to 1.6.1
  * build(deps): bump github.com/prometheus/common from 0.39.0 to 0.40.0
  * Move to aquasecurity/trivy-action instead
  * update relevant deps
  * build(deps): bump alpine from 3.17.1 to 3.17.2
* Sun Mar 24 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.12.1:
  * prepare for 1.12.1 release
  * drop unnecessary replacement for go-restful CVE
  * build(deps): bump docker/build-push-action from 3 to 4
  * build(deps): bump github.com/containrrr/shoutrrr from 0.7.0 to 0.7.1
  * build(deps): bump github.com/containrrr/shoutrrr from 0.6.1 to 0.7.0
  * build(deps): bump github.com/spf13/viper from 1.14.0 to 1.15.0
  * build(deps): bump docker/metadata-action from 4.2.0 to 4.3.0
  * build(deps): bump docker/metadata-action from 4.1.1 to 4.2.0 (#716)
  * build(deps): bump alpine from 3.17.0 to 3.17.1 (#714)
  * build(deps): bump nick-invision/retry from 2.8.2 to 2.8.3
  * build(deps): bump actions/stale from 6 to 7
  * update golang.org/x/net dep
* Sun Mar 24 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.12.0:
  * chore: updated image
  * build(deps): bump github.com/prometheus/common from 0.38.0 to 0.39.0 (#710)
  * build(deps): bump helm/kind-action from 1.4.0 to 1.5.0
  * update for k8s 1.26
  * build(deps): bump github.com/prometheus/common from 0.37.0 to 0.38.0
  * document where to find the invidivual repositories
  * move documentation to kured.dev
  * build(deps): bump alpine from 3.16.3 to 3.17.0 (#704)
  * use website logos
  * make the governance ours
  * Import GOVERNANCE-maintainer.md template
  * add mailing list
  * build(deps): bump alpine from 3.16.2 to 3.16.3
  * Fix location of Dockerfile for dependabot
  * build(deps): bump lycheeverse/lychee-action from 1.5.2 to 1.5.4
  * build(deps): bump github.com/prometheus/client_golang
  * build(deps): bump github.com/spf13/viper from 1.13.0 to 1.14.0
* Sun Mar 24 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.11.0:
  * chore: bump to 1.11.0
  * build(deps): bump lycheeverse/lychee-action from 1.5.1 to 1.5.2 (#691)
  * build(deps): bump github.com/prometheus/client_golang
  * build(deps): bump Jerome1337/golint-action from 1.0.2 to 1.0.3
  * adjust link to CONTRIBUTING file
  * brown paper bag for #686
  * Replace set-output with GITHUB_OUTPUT
  * simplify the setup of go in workflows
  * Move DEV doc to be CONTRIBUTING.md
  * Remove deadlink to k8s 1.10 support branch
  * website: we don't use analytics
  * Add CLOMonitor badge
  * Move to lychee for checking links
  * Add license scan report and status
  * build(deps): bump github.com/spf13/cobra from 1.6.0 to 1.6.1
  * build(deps): bump github.com/stretchr/testify from 1.8.0 to 1.8.1
  * Add ArtifactHub badge
  * build(deps): bump docker/metadata-action from 4.1.0 to 4.1.1
  * update x/net and x/text to include security fix
  * build(deps): bump nick-invision/retry from 2.8.1 to 2.8.2 (#669)
  * build(deps): bump docker/metadata-action from 4.0.1 to 4.1.0
  * add CodeQL cron job
  * build(deps): bump github.com/spf13/cobra from 1.5.0 to 1.6.0
  * build(deps): bump gotest.tools/v3 from 3.3.0 to 3.4.0 (#663)
  * update meeting day
  * fix: fix spdx-sbom-handling (#661)
  * feat: Integrate GoReleaser, Cosign and Syft (#595)
  * Update to latest k8s
  * build(deps): bump helm/kind-action from 1.3.0 to 1.4.0
  * build(deps): bump actions/stale from 5 to 6
  * build(deps): bump docker/metadata-action from 3.3.0 to 4.0.1
  * Remove reference to dockerhub image
  * Use github token instead of bot accounts
  * stop publishing to Docker Hub
  * Changed weaveworks to kubereboot in many places
  * Remove charts from repo
  * Add footer to README
  * require DCO from now on
  * Add a warning to inform users about move
  * Update golang and x/net
  * ci: Ignore cache to pick latest matching go ver
  * Update Slack information - point to CNCF Slack.
  * Update maintainer email address
  * build(deps): bump github.com/spf13/viper from 1.12.0 to 1.13.0 (#626)
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Tue Nov  7 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.19: unnumbered patches are no longer
  supported.
* Wed Sep  7 2022 kastl@b1-systems.de
- refresh patch kured-imagePullPolicy.patch
- Update to version 1.10.2:
  * chore: prepare release 1.10.2
  * build(deps): bump helm/chart-testing-action from 2.2.1 to 2.3.0 (#618)
  * build(deps): bump alpine from 3.16.1 to 3.16.2 in /cmd/kured (#617)
  * build(deps): bump github.com/prometheus/client_golang (#616)
  * build(deps): bump nick-invision/retry from 2.8.0 to 2.8.1 (#615)
  * build(deps): bump nick-invision/retry from 2.7.1 to 2.8.0 (#613)
  * build(deps): bump nick-invision/retry from 2.7.0 to 2.7.1
  * build(deps): bump github.com/sirupsen/logrus from 1.8.1 to 1.9.0 (#600)
  * fix: helm chart, use standard labels/best practice (#605)
  * update command line flags in README (#607)
  * build(deps): bump github.com/prometheus/common from 0.35.0 to 0.37.0 (#599)
  * build(deps): bump alpine from 3.16.0 to 3.16.1 in /cmd/kured
  * build(deps): bump github.com/stretchr/testify from 1.7.5 to 1.8.0
  * build(deps): bump github.com/containrrr/shoutrrr from 0.6.0 to 0.6.1
  * ci: address Azure/container-scan regression (#606)
* Fri Jul  1 2022 jkowalczyk@suse.com
- Update to version 1.10.1:
  * prepare release 1.10.1 (#594)
  * Updated helm charts with new message template flag (#589)
  * add CoC file
  * added notification when uncordoning (#587)
  * build(deps): bump github.com/stretchr/testify from 1.7.4 to 1.7.5 (#588)
  * build(deps): bump github.com/stretchr/testify from 1.7.3 to 1.7.4 (#583)
  * build(deps): bump github.com/spf13/cobra from 1.4.0 to 1.5.0 (#584)
  * build(deps): bump gotest.tools/v3 from 3.2.0 to 3.3.0 (#582)
  * build(deps): bump github.com/prometheus/common from 0.34.0 to 0.35.0 (#580)
  * build(deps): bump github.com/stretchr/testify from 1.7.2 to 1.7.3 (#581)
  * build(deps): bump helm/kind-action from 1.2.0 to 1.3.0 (#578)
  * build(deps): bump guyarb/golang-test-annoations from 0.5.1 to 0.6.0 (#577)
- Refresh kured-imagePullPolicy.patch
- Update to BuildRequires: golang(API) >= 1.17 from pinned 1.16
* Thu Jun  9 2022 jkowalczyk@suse.com
- Update to version 1.10.0:
  * Release 1.10.0 preparation (#572)
  * build(deps): bump actions/setup-python from 3 to 4 (#576)
  * build(deps): bump docker/setup-buildx-action from 1 to 2 (#575)
  * build(deps): bump docker/build-push-action from 2 to 3 (#573)
  * build(deps): bump docker/setup-qemu-action from 1 to 2 (#574)
  * Added support for multi-arch image build (#496)
  * Downgrade kind-images for 1.22.x and 1.23.x (#569)
  * build(deps): bump github.com/stretchr/testify from 1.7.1 to 1.7.2 (#571)
  * build(deps): bump github.com/containrrr/shoutrrr from 0.5.3 to 0.6.0 (#570)
  * updated slack-related documentation (#568)
  * build(deps): bump github.com/spf13/viper from 1.11.0 to 1.12.0 (#565)
  * improved documentation covering slack usage (#564)
  * build(deps): bump alpine from 3.15.4 to 3.16.0 in /cmd/kured (#560)
  * tolerate both 1.24+ and prior control plane taints (#562)
  * build: small debug commands for nightly job
  * feat: update kubernetes dependencies (#552)
  * Use clean patch to update node labels. Fixes #553
  * Change after-reboot-node-labels flag to post-reboot-node-labels
  * Add a note about adding multiple node labels
  * Use Errorf instead of Fatalf for node label logging
  * Tidy node labelling code
  * Update readme with node labelling info
  * Add verification for node labelling flags
  * Add node labelling
  * strip unnecessary quotes for notify-url configurations
  * ci: substring suffix inside quotes
  * ci: always use the latest golang patch version
  * build(deps): bump github.com/prometheus/client_golang
  * bump Helm chart version to v2.14.1
  * helm: fix tolerations on 1.24
  * build(deps): bump docker/login-action from 1 to 2
  * helm: ensure kured on 1.24 gets the correct toleration
  * build(deps): bump nick-invision/retry from 2.6.0 to 2.7.0
  * build(deps): bump gotest.tools/v3 from 3.1.0 to 3.2.0
  * build(deps): bump github.com/prometheus/common from 0.33.0 to 0.34.0
  * feat: use go@1.17
  * build(deps): bump github.com/spf13/viper from 1.10.1 to 1.11.0
  * build(deps): bump guyarb/golang-test-annoations from 0.5.0 to 0.5.1
  * build(deps): bump github.com/containrrr/shoutrrr from 0.5.2 to 0.5.3
  * build(deps): bump actions/setup-go from 2 to 3
  * build(deps): bump actions/stale from 4 to 5
  * build(deps): bump alpine from 3.15.3 to 3.15.4 in /cmd/kured
  * fixed yamllint error #521
  * updated README with additional values #521
  * bump chart version to 2.13.0 #521
  * adding value containerSecurityContext to helm chart #521
  * Update README.md
  * build(deps): bump github.com/prometheus/common from 0.32.1 to 0.33.0
  * retry cordon + drain if fail, keep lock
* Wed Mar 30 2022 jkowalczyk@suse.com
- Update to version 1.9.2:
  * update to alpine@3.15.3
  * build(deps): bump alpine from 3.15.1 to 3.15.2 in /cmd/kured
  * build(deps): bump alpine from 3.15.0 to 3.15.1 in /cmd/kured
  * build(deps): bump github.com/stretchr/testify from 1.7.0 to 1.7.1
  * Bump chart version to 2.12.0
  * Mention dynamic Slack parameters
  * Bump chart version
  * Use templating in Slack URL, channel and username
  * build(deps): bump actions/checkout from 2 to 3
  * build(deps): bump helm/chart-testing-action from 2.2.0 to 2.2.1
  * build(deps): bump github.com/spf13/cobra from 1.3.0 to 1.4.0
  * Add Helm values example
  * docs: add sentinel command example for RHEL family
  * build(deps): bump actions/setup-python from 2 to 3
  * build(deps): bump github.com/prometheus/client_golang
  * build(deps): bump github.com/prometheus/client_golang
  * build(deps): bump gotest.tools/v3 from 3.0.3 to 3.1.0
  * Add ability to define ds annotations in helm chart
  * build(deps): bump helm/chart-testing-action from 2.1.0 to 2.2.0
* Fri Jan  7 2022 kastl@b1-systems.de
- Update to version 1.9.1:
  * prepare release 1.9.1
  * small fix in deprecation log messages
  * don't print env variable values in the logs (some are sensitive)
  * prepare 1.9.0
  * Update README.md
  * Add chart configuration for json logging
- rebase patch kured-imagePullPolicy.patch onto 1.9.1
* Fri Jan  7 2022 Johannes Kastl <kastl@b1-systems.de>
- BuildRequire go 1.16 or higher
* Fri Jan  7 2022 kastl@b1-systems.de
- Update to version 1.9.0:
  * build(deps): bump github.com/spf13/viper from 1.10.0 to 1.10.1
  * build(deps): bump github.com/spf13/cobra from 1.2.1 to 1.3.0
  * build(deps): bump github.com/spf13/viper from 1.9.0 to 1.10.0
  * build(deps): bump nick-invision/retry from 2.5.1 to 2.6.0
  * build(deps): bump github.com/spf13/viper from 1.8.1 to 1.9.0
  * update to test against k8s 1.2{1,2,3} kind images
  * ensure go version for tests
  * Update k8s dependencies to 0.22.4
  * update image tag to 1.8.2
  * use sprintf for value in log
  * minor restructure and adding log for flag to env var binding
  * dedup const block
  * address review comments
  * bind environment variables to cobra flags with viper
  * Exclude terminated pods from the blocking mechanism
* Fri Jan  7 2022 kastl@b1-systems.de
- Update to version 1.8.2:
  * fix ghcr.io login
  * Move to GHCR as a backup for Docker Hub
  * build(deps): bump alpine from 3.14 to 3.15.0 in /cmd/kured
  * follow up to #465
  * update docker images too
  * feat: update chart to 2.10.1 w/ 1.8.1 kured image
  * build(deps): bump nick-invision/retry from 2.5.0 to 2.5.1
  * Support json logformatter
  * build(deps): bump github.com/prometheus/common from 0.32.0 to 0.32.1
  * build(deps): bump github.com/prometheus/common from 0.31.1 to 0.32.0
  * build(deps): bump github.com/containrrr/shoutrrr from 0.5.1 to 0.5.2
  * feat: update to 1.8.0
  * feat: add also missing prefer-no-schedule-taint
  * feat: add reboot-sentinel-command to helm-chart
  * fix: correct indent ref: #447
  * docs: updated version table
  * removed notifications/slack package
  * Add reboot-delay CLI argument to docs, manifests and helm charts
  * Add --alert-firing-only parameter to chart
* Fri Jan  7 2022 kastl@b1-systems.de
- Update to version 1.8.0:
  * Revert "[WIP] Add quay.io as second registry"
  * Bump nick-invision/retry from 2.4.1 to 2.5.0
  * doc: some clarification for release-docs
  * Bump github.com/prometheus/common from 0.31.0 to 0.31.1
  * Add jackfrancis to MAINTAINERS
  * build: add quay.io as second registry
  * update to go 1.16 (follow the load of k8s 1.21)
  * build: added k8s@1.22 and dropped k8s@1.19
  * feat: updated to k8s@1.21
  * fix: don't use nil context in drain helper
  * Bump github.com/prometheus/common from 0.30.0 to 0.31.0
  * Bump guyarb/golang-test-annoations from 0.4.0 to 0.5.0
  * Add force-reboot and drain timeouts to chart config and ds
  * fix: do not use array for stale action (#433)
  * Bump github.com/containrrr/shoutrrr from 0.5.0 to 0.5.1
  * build: updated to alpine@3.14
  * Bump github.com/containrrr/shoutrrr from 0.4.4 to 0.5.0
  * Change default updateStrategy to RollingUpdate (#420)
  * Add `reboot-delay` command line argument
  * Add --alert-firing-only parameter to only consider firing alerts
  * Bump github.com/prometheus/common from 0.29.0 to 0.30.0 (#414)
  * Restructuring Prometheus client, added unit-tests to regex-queries active alerts (#386)
  * Added possibility to mount volumes (#407)
  * fix: common default reboot command for code and chart
  * Bump actions/stale from 3.0.19 to 4
  * link to versioned shoutrrr docs
  * Bump github.com/spf13/cobra from 1.1.3 to 1.2.1
  * Bump helm/kind-action from 1.1.0 to 1.2.0
  * our 'good first issue' issue label has no '-', add 'keep'
  * Added rebootCommand values (#394)
  * Bump nick-invision/retry from 2.4.0 to 2.4.1
  * Bump github.com/prometheus/common from 0.25.0 to 0.29.0
  * fix slack deprecation notice
  * Bump helm/chart-testing-action from 2.0.1 to 2.1.0
  * sort parameters alphabetically
  * Add documentation for lockReleaseDelay parameter
  * Add lockReleaseDelay parameter to helm chart
  * doc: update image-version
  * update chart definition to include --notify-url
* Fri Jan  7 2022 Johannes Kastl <kastl@b1-systems.de>
- rebase patch systemctl-path.patch to 1.7.1
* Fri Jan  7 2022 kastl@b1-systems.de
- Update to version 1.7.0:
  * doc: add compat-line for 1.7.0
  * use latest kind
  * Bounce kubernetes testing versions
  * Bump github.com/prometheus/common from 0.24.0 to 0.25.0
  * Bump actions/stale from 3.0.18 to 3.0.19
  * update golang.org/x/crypto - break out of #349
  * Bump github.com/prometheus/common from 0.23.0 to 0.24.0
  * Clarify and simplify tests
  * Bump github.com/prometheus/common from 0.18.0 to 0.23.0
  * docu: update url for ms teams notifications, fixes #362
  * Use stable kind-action
  * Bump github.com/prometheus/client_golang from 1.8.0 to 1.10.0
  * Bump github.com/containrrr/shoutrrr from 0.4.3 to 0.4.4
  * Bump github.com/containrrr/shoutrrr from 0.4.2 to 0.4.3
  * Update kured-ds.yaml
  * Reduce false positives in chart testing
  * Add prometheus export metrics functional testing
  * Add parameter for delaying release of lock
  * update to latest k8s deps of 1.20 branch
  * Expose SkipWaitForDeleteTimeoutSeconds and explicitly return when cordonning fails
  * Update the default drain timeout to be infinite
  * Don't panic if the cordon fails and force-reboot is true
  * Refactor force-drain to be a drain-timeout in general
  * chore: retry daemonset get operations
  * Add force-reboot after force-timeout duration has been exceeded
  * Bump github.com/containrrr/shoutrrr from 0.4.1 to 0.4.2
  * Update deps
  * Add chart-testing target-branch
  * udpate Dev docs to latest
  * Update github actions
  * Change default branch to 'main'.
  * feat: use chart appVersion as default image-tag
  * Fix invoke reboot for custom commands
  * Implement universal notification mechanism
  * Bump guyarb/golang-test-annoations from v0.3.0 to v0.4.0
  * Add go tests
  * Fix the Fatal calls using formatting
  * Add flexible commands parameters
  * Refactor reboot blocks
  * Fix periodic jobs
  * Update the deprecated DeleteLocalData
  * Bouncing go.mod with latest kubernetes packages
  * change comment accordingly
  * extend close-duration for stale issues and prs
  * update chart definition to include --annotate-nodes
  * Adding a MAINTAINERS file
  * update to alpine 3.13
  * Bump github.com/sirupsen/logrus from 1.8.0 to 1.8.1
  * add node annotations
  * always drain before reboot
  * Bump actions/stale from v3.0.17 to v3.0.18
  * Bump actions/stale from v3.0.16 to v3.0.17
  * Bump github.com/sirupsen/logrus from 1.7.0 to 1.8.0
  * Bump github.com/spf13/cobra from 1.1.2 to 1.1.3
  * Bump github.com/spf13/cobra from 1.1.1 to 1.1.2
  * Point to CNCF Code of Conduct
  * Bump actions/stale from v3.0.15 to v3.0.16
  * add podLabels parameter
  * Bump actions/stale from v3.0.14 to v3.0.15
  * change taint config to be disabled by default
  * Update helm chart README using Make
  * Update helm chart
  * remove taint in case the reboot is not needed anymore
  * updated README
  * cache taint state to avoid unnecessary API calls
  * Allow to disable tainting during pending node reboot by setting the taint name to an empty string.
  * fixed type & renamed variable
  * taint node with PreferNoSchedule to prevent receiving (and double draining) additional pods from other rebooting nodes
  * fixed call of log.Fatal instead of log.Fatalf
  * avoid indentations to ease readability
  * Expose the service name and maxUnavailable for rolling updates in the helm chart
* Tue Feb  2 2021 kukuk@suse.com
- Update to version 1.6.1:
  - add additional parameters to override the drain/reboot slack messages
  - rename message template parameters so they are not related to slack
  - Improve coordinated reboot output
  - Add more logs into gates
  - Added support for time wrap in timewindow.Contains
* Tue Nov 24 2020 kukuk@suse.com
- Update to version 1.5.1:
  * rename annotation-ttl to lock-ttl in all places, follow-up to #213
  * Drain: allow pods grace period to terminate
  * Prepare 1.5.1 release
  * Add lint job
  * Make lint happier in pkg folder
  * Make lint happier
  * Remove prom-active-alerts
  * update docs following #210
  * run 'go mod tidy'
  * Replaced --annotationTTL with --lockTTL and made it work correctly
  * Refactor drain/uncordon
  * Remove kubectl exception in container scanning
  * Bump prometheus
  * Use kubectl as library instead of calling from cli
  * fix: Follow DKL-DI-0004 guideline
  * feat: Add security scanning into CI
  * add missing quote - thanks Karan Arora for reporting
  * Bump helm chart version
  * Remove quote for parameter alert-filter-regexp
  * Release helper
* Mon Sep 21 2020 kukuk@suse.com
- Update to version 1.5.0:
  * Prepare 1.5.0 release
  * Bump helm/kind-action from v1.0.0-rc.1 to v1.0.0
  * Bump helm/chart-testing-action from v1.0.0-rc.2 to v1.0.0
  * Add dependabot
  * Prepare for k8s release 1.19 (Aug 25)
* Fri Aug 14 2020 kukuk@suse.com
- Update to version 1.4.5:
  * document how releases are town wrt Helm bits
  * bump versions for 1.4.5 release
  * Use nindent, not indent
  * chart: update readme
  * Bump chart version
  * Add missing 'end'
  * Chart: Support extraEnvVars
  * update install instructions to use latest
  * update chart version
  * Prep for 1.4.4 release
  * bump and fix
  * split matchLabels template
  * restructured and improved service
* Tue Jun 30 2020 dmueller@suse.com
- Update to version 1.4.3:
  * bump and fix
  * split matchLabels template
  * restructured and improved service
  * bumped kured to upcoming 1.4.3 fixed servicemonitor indent fixed quotes for arguments
  * update things for 1.4.2 release
  * Use GITHUB_TOKEN for releasing chart
  * make markdownlint happier
  * update version
  * prepare chart-release for 1.4.1
  * Revert #139
- use obs-service for regenerating vendor.tar.gz
* Tue Jun 30 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 1.4.2
  - Adding --annotation-ttl for automatic unlock
- Refresh vendor.tar.xz
* Mon May 18 2020 Thorsten Kukuk <kukuk@suse.com>
- kured-imagePullPolicy.patch: always update the image
* Sun May 17 2020 Thorsten Kukuk <kukuk@suse.com>
- systemctl-path.patch: last systemd update removed symlinks
  from /bin ...
* Mon May 11 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 1.4.0
  - Updated kubectl, client-go, etc to k8s 1.17 (#127, #135)
  - Update to go 1.13 (#130)
  - print node id when commanding reboot (#134)
* Wed Apr 22 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build-dependency: we require golang(API) 1.12, not the exact
  go package version 1.12.
* Mon Mar  2 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 1.3.0
  - Update k8s client tools to 1.15.x
  - Ad Slack channel name configuration
  - Add reboot window
- Obsoletes k8s-1.14.diff
- Remove kured-telemetrics.patch, chances that upstream accepts
  any third party code are nearly zero.
- Update vendor.tar.xz
* Mon Jun 24 2019 kukuk@suse.de
- k8s-1.14.diff: kubernetes 1.14.1 support from git
* Wed Jun  5 2019 kukuk@suse.de
- Fix path to image in manifest
* Wed May 22 2019 kukuk@suse.de
- Update to version 1.2.0
  - support newer kubernetes versions
- Adjust kured-telemetrics.patch
- Update vendor.tar.gz with recent versions
* Sat Apr  6 2019 kukuk@suse.de
- Enable building on s390x
* Thu Mar 28 2019 Jan Engelhardt <jengelh@inai.de>
- Combine %%setup calls.
* Thu Mar 28 2019 kukuk@suse.de
- kured-telemetrics.patch: add hooks for telemetrics data
- Renamed kured-yaml to kured-k8s-yaml to follow new policy
* Thu Feb 28 2019 kukuk@suse.de
- Change path in yaml file to point to official container image
* Fri Jan 18 2019 kukuk@suse.de
- Create a correct yaml file to download and run the kured container
  image in a kubernetes cluster
- Create new subpackage containing only the yaml file, so that
  people using the container don't need to install the not needed
  full package.
* Thu Nov 15 2018 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to kured 1.1.0
- Upstream bumped dependency on go1.10 via dependency k8s.io/client-go 0.9.0
  https://github.com/kubernetes/client-go
- Provide dependencies in separate vendor.tar.gz
- Improvements
  * RBAC support
  * Use the systemctl in the host mount namespace to effect reboots, reducing
    image size and eliminating the potential for incompatibility
  * Notify Slack on drain in addition to reboot
  * Pass through log output from invoked kubectl commands
  * Tolerate NoSchedule taint on node-role.kubernetes.io/master
  * Fixed reversal of daemonset name/namespace arguments and comments in the
    manifest
- Kubernetes Version Compatibility
  * The daemon image contains a 1.12.x k8s.io/client-go and kubectl binary for
    the purposes of maintaining the lock and draining worker nodes. Kubernetes
    aims to provide forwards & backwards compatibility of one minor version
    between client and server, so this should work on 1.11.x and 1.13.x.
  * Tested in minikube on 1.11.4, 1.12.1 & 1.13.0-alpha.2
  * Tested in production on 1.11.2 & 1.12.2
* Thu Sep 13 2018 jkowalczyk@suse.com
- Remove hardcoded GOARCH=amd64 and GOOS=linux
- Revise go build arg -ldflags and add -buildmode=pie
- Together these fix rpmlint warnings:
  * position-independent-executable-suggested
  * statically-linked-binary
- Upstream kured project code imports package as 'context'. Bump BuildRequires
  to go1.7 wherein import path for package context graduates from
  'golang.org/x/net/context' to the standard library as 'context'.
  https://golang.org/doc/go1.7#context
- Bump release number
* Wed Sep 12 2018 jkowalczyk@suse.com
- Initial packaging of upstream master branch @ 5731b98 (tagged 1.0.0 + 24)
- Include 24 commits since release 1.0.0 updating kubernetes version support
- Dependency sources vendored via dep ensure per upstream build instructions
- Man page converted from README.md, some HTML formatting artifacts present
- rpmlint warning: position-independent-executable-suggested
  * go1.11 currently in review status supports option -buildmode=pie
- rpmlint warning: statically-linked-binary
  * Go binaries are generally statically linked
